@@ -4,6 +4,6 @@ use warnings;
 
 package WWW::Shopify::Liquid::Filter::AssetUrl; use base 'WWW::Shopify::Liquid::Filter';
 sub max_arguments { return 0; }
-sub operate { die new WWW::Shopify::Liquid::Renderer::Unimplemented(__PACKAGE__); }
+sub operate { die new WWW::Shopify::Liquid::Exception::Renderer::Unimplemented($_[0]); }
 
 1;
\ No newline at end of file
