@@ -3,6 +3,11 @@ use strict;
 use warnings;
 
 package WWW::Shopify::Liquid::Filter::NewlineToBr; use base 'WWW::Shopify::Liquid::Filter';
-sub operate {  my $str = $_[2]; $str =~ s/\n/<br>/g; return $str }
+sub operate { 
+	my $str = $_[2];
+	$str = '' unless defined $str;
+	$str =~ s/[\r\n]+/<br\/>/g; 
+	return $str;
+}
 
 1;
\ No newline at end of file
