@@ -5,6 +5,10 @@ use warnings;
 use HTML::Strip;
 
 package WWW::Shopify::Liquid::Filter::StripHtml; use base 'WWW::Shopify::Liquid::Filter';
-sub operate { my $hs = HTML::Strip->new(); my $text = $hs->parse($_[2]); $hs->eof; return $text; }
+sub operate {
+	my ($self, $hash, $argument) = @_;
+	$argument =~ s/<[^>]+>//g;
+	return $argument;
+}
 
 1;
\ No newline at end of file
