@@ -6,24 +6,27 @@ package WWW::Shopify::Liquid::Operator;
 use base 'WWW::Shopify::Liquid::Element';
 sub new { 
 	my $package = shift;
-	my $self = bless { core => shift, operands => undef }, $package;
+	my $self = bless { line => shift, core => shift, operands => undef }, $package;
 	$self->{operands} = [@_] if int(@_) >= 1;
 	return $self;
 }
 sub operands { my $self = shift; $self->{operands} = [@_]; return $self->{operands}; }
 
 sub tokens { return map { $_->tokens } (@{$_[0]->{operands}}) }
+sub arity { return "binary"; }
+sub fixness { return "infix"; }
 
 sub process {
-	my ($self, $hash, $action) = @_;
-	my ($op1, $op2) = ($self->{operands}->[0], $self->{operands}->[1]);
-	$op1 = $op1->$action($hash) unless $self->is_processed($op1);
-	$op2 = $op2->$action($hash) unless $self->is_processed($op2);
-	if ((!$self->is_processed($op1) || !$self->is_processed($op2)) && $action eq "optimize") {
-		$self->{operands} = [$op1, $op2];
+	my ($self, $hash, $action, $pipeline) = @_;
+	my @ops = @{$self->{operands}};
+	$ops[$_] = $ops[$_]->$action($pipeline, $hash) for (grep { !$self->is_processed($ops[$_]) } (0..$#ops));
+	
+	if (int(grep { !$self->is_processed($_) } @ops) > 0 && $action eq "optimize") {
+		$self->{operands} = \@ops;
 		return $self;
 	}
-	return $self->operate($hash, $action, $op1, $op2);
+	$pipeline->security->check_operate($self, $hash, $action, @ops);
+	return $self->operate($hash, $action, @ops);
 }
 sub priority { return 0; }
 # If we require a grouping, it means that it must be wrapped in parentheses, due to how Shopify works. Only relevant for reconversion.
