@@ -10,7 +10,9 @@ sub priority { return 5; }
 sub operate { 
 	my ($self, $hash, $action, $op1, $op2) = @_;
 	return undef unless defined $op1 && defined $op2;
-	return $op1 =~ m/$op2/;
+	my @groups = ($op1 =~ m/$op2/);
+	return undef if (int(@groups) == 0);
+	return \@groups;
 }
 
 1;
\ No newline at end of file
