@@ -18,4 +18,7 @@ sub new {
 	return bless $self, $package;
 }
 
+sub strip_left_end { $_[0]->{strip_left_end} = $_[1] if @_ > 1; return $_[0]->{strip_left_end}; }
+sub strip_right_end { $_[0]->{strip_right_end} = $_[1] if @_ > 1; return $_[0]->{strip_right_end}; }
+
 1;
\ No newline at end of file
