@@ -9,8 +9,8 @@ sub min_arguments { return 1; }
 sub max_arguments { return 1; }
 
 sub process {
-	my ($self, $hash) = @_;
-	my $result = $self->{arguments}->[0]->process($hash);
+	my ($self, $hash, $action, $pipeline) = @_;
+	my $result = $self->{arguments}->[0]->$action($pipeline, $hash);
 	return $self if blessed($result);
 	return '';
 }
